# aiogemini

This package provides implementations of a client and server speaking the
[gemini protocol][gemini] built on the python stdlib asyncio primitives.

it is a work in progress.

try `python -m aiogemini.server` or `python -m aiogemini.client` for something
to look at.


[gemini]: gemini://gemini.circumlunar.space/
